Creeper – Minecraft Wiki
Description: A creeper is a common hostile mob that quietly approaches a player, hisses, and if not retreated from in time, will explode. Creeper explosions can destroy blocks and deal massive amounts of damage, which can be completely blocked using a shield.

# Creeper

From Minecraft Wiki
Jump to navigation Jump to search
For other uses, see Creeper (disambiguation).
Creeper

Health points | 20HP × 10
Behavior | Hostile
Mob type | Monster
Attack strength | Explosion: Explosion varies by proximity and difficulty. Maximum damage: Regular: Easy: 22.5HP × 11.25 Normal: 43HP × 21.5 Hard: 64.5HP × 32.25 Charged: Easy: 43.5HP × 21.75 Normal: 85HP × 42.5 Hard: 127.5HP × 63.75
Hitbox size | In Java Edition: Height: 1.7 blocks Width: 0.6 blocks In Bedrock Edition: Height: 1.8 blocks Width: 0.6 blocks
Spawn | Regular: Light level of 0 Charged: When lightning strikes within 4 blocks of a Regular Creeper
Usable items | Flint and Steel Fire Charge ‌[Java Edition only]

    {
        "title": "Creeper",
        "rows": [
            {
                "field": "20<span class=\"hidden-alt-text\">HP</span><span class=\"nowrap mc-hearts\"><span class=\"iconbar pixel-image nowrap\" style=\"--icon-offset:-1px;\" title=\"1  heart\">(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)</span> × 10</span>",
                "label": "(link to Health article, displayed as Health points)"
            },
            {
                "field": "Hostile",
                "label": "Behavior"
            },
            {
                "field": "<span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:EntitySprite monster.png article, displayed as 16x16px|link=Monster|alt=|class=pixel-image|)</span>(link to Monster article, displayed as <span class=\"sprite-text\">Monster</span>)</span>",
                "label": "(link to Mob type article, displayed as Mob type)"
            },
            {
                "field": "(values exceeds 1000 characters...)",
                "label": "Attack<br/>strength"
            },
            {
                "field": "'''In (link to Java Edition article, displayed as ''Java Edition''):'''<br>\nHeight: 1.7 blocks<br>Width: 0.6 blocks<br>\n'''In (link to Bedrock Edition article, displayed as ''Bedrock Edition''):'''<br>\nHeight: 1.8 blocks<br>Width: 0.6 blocks",
                "label": "(link to Hitbox article, displayed as Hitbox size)"
            },
            {
                "field": "'''Regular:'''<br>Light level of 0<br>\n'''Charged:'''<br>\nWhen <span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:EntitySprite lightning.png article, displayed as 16x16px|link=lightning|alt=|class=pixel-image|)</span>(link to lightning article, displayed as <span class=\"sprite-text\">lightning</span>)</span> strikes within 4 blocks of a Regular Creeper",
                "label": "(link to Mob spawning article, displayed as Spawn)"
            },
            {
                "field": "\n*   <span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:ItemSprite flint-and-steel.png article, displayed as 16x16px|link=Flint and Steel|alt=|class=pixel-image|)</span>(link to Flint and Steel article, displayed as <span class=\"sprite-text\">Flint and Steel</span>)</span>   <br>\n*   <span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:ItemSprite fire-charge.png article, displayed as 16x16px|link=Fire Charge|alt=|class=pixel-image|)</span>(link to Fire Charge article, displayed as <span class=\"sprite-text\">Fire Charge</span>)</span>   ‌<sup class=\" nowrap Inline-Template \" title=\"\">[<i><span title=\"This statement only applies to Java Edition\">(link to Java Edition article, displayed as Java Edition)  only</span></i>]</sup>",
                "label": "Usable items"
            }
        ],
        "invimages": [
            "Creeper Spawn Egg"
        ],
        "images": [
            "Creeper.png",
            "Charged Creeper.gif"
        ]
    }

A creeper is a common hostile mob that quietly approaches a player, hisses, and if not retreated from in time, will explode. Creeper explosions can destroy blocks and deal massive amounts of damage, which can be completely blocked using a shield.

When struck by lightning, a creeper becomes a charged creeper, which amplifies its explosion power and enables mob heads to be obtained from piglins, zombies, skeletons and other creepers it kills.

Due to its distinctive appearance and unique destructive method of attack, the creeper has become one of the most iconic mobs of Minecraft, being featured in promotional material and merchandise.

## Spawning

Creepers naturally spawn in the Overworld on solid blocks with a light level of 0, except in mushroom fields and deep dark biomes. In Bedrock Edition, creepers also do not spawn in rivers, frozen rivers, and snowy plains. They spawn individually in Bedrock Edition and in groups of four in Java Edition.

In Bedrock Edition, there is a density limit of five creepers on the surface of Overworld.

Creeper spawns in:

Category: Monster | Java Edition | Bedrock Edition
--- | --- | ---
Spawn area | Spawn weight | Spawn chance | Group size | Spawn weight | Group size
Bamboo Jungle | 100⁄515 | 19.42% | 4 | 100 | 1
Meadow | 100⁄515 | 19.42% | 4 | 100 | 1
Windswept Hills | 100⁄515 | 19.42% | 4 | 100 | 1
Eroded Badlands | 100⁄515 | 19.42% | 4 | 100 | 1
Frozen Peaks | 100⁄515 | 19.42% | 4 | 100 | 1
Jagged Peaks | 100⁄515 | 19.42% | 4 | 100 | 1
Grove | 100⁄515 | 19.42% | 4 | 100 | 1
Old Growth Birch Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Snowy Beach | 100⁄515 | 19.42% | 4 | 100 | 1
Stony Peaks | 100⁄515 | 19.42% | 4 | 100 | 1
Snowy Slopes | 100⁄515 | 19.42% | 4 | 100 | 1
Sparse Jungle | 100⁄515 | 19.42% | 4 | 100 | 1
Birch Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Flower Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Beach | 100⁄515 | 19.42% | 4 | 100 | 1
Taiga | 100⁄515 | 19.42% | 4 | 100 | 1
Lush Caves | 100⁄515 | 19.42% | 4 | 100 | 1
Wooded Badlands | 100⁄515 | 19.42% | 4 | 100 | 1
Snowy Taiga | 100⁄515 | 19.42% | 4 | 100 | 1
Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Windswept Gravelly Hills | 100⁄515 | 19.42% | 4 | 100 | 1
Badlands | 100⁄515 | 19.42% | 4 | 100 | 1
Windswept Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Pale Garden | 100⁄515 | 19.42% | 4 | 100 | 1
Ice Spikes | 100⁄515 | 19.42% | 4 | 100 | 1
Stony Shore | 100⁄515 | 19.42% | 4 | 100 | 1
Old Growth Spruce Taiga | 100⁄515 | 19.42% | 4 | 100 | 1
Dark Forest | 100⁄515 | 19.42% | 4 | 100 | 1
Desert | 100⁄515 | 19.42% | 4 | 100 | 1
Cherry Grove | 100⁄515 | 19.42% | 4 | 100 | 1
Mangrove Swamp | 100⁄516 | 19.38% | 4 | 100 | 1
Frozen River | 100⁄516 | 19.38% | 4 | — | —
Swamp | 100⁄516 | 19.38% | 4 | 100 | 1
Jungle | 100⁄517 | 19.34% | 4 | 100 | 1
Lukewarm Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Warm Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Sunflower Plains | 100⁄520 | 19.23% | 4 | 100 | 1
Deep Cold Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Deep Frozen Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Snowy Plains | 100⁄520 | 19.23% | 4 | — | —
Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Deep Lukewarm Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Plains | 100⁄520 | 19.23% | 4 | 100 | 1
Deep Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Savanna Plateau | 100⁄520 | 19.23% | 4 | 100 | 1
Frozen Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Windswept Savanna | 100⁄520 | 19.23% | 4 | 100 | 1
Savanna | 100⁄520 | 19.23% | 4 | 100 | 1
Cold Ocean | 100⁄520 | 19.23% | 4 | 100 | 1
Old Growth Pine Taiga | 100⁄540 | 18.52% | 4 | 100 | 1
Dripstone Caves | 100⁄610 | 16.39% | 4 | 100 | 1
River | 100⁄615 | 16.26% | 4 | — | —

## Drops

### On death

Java Edition:

Item | Quantity / Chance / Average
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0–2 | 66.67% | 1.00 | 0–3 | 83.33% | 1.50 | 0–4 | 91.67% | 2.00 | 0–5 | 94.44% | 2.50
| Music Disc[A][B] | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00
| Creeper Head[C] | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00

Item | Quantity / Chance / Average
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0–2 | 2⁄3 | 1 | 0–3 | 5⁄6 | 3⁄2 | 0–4 | 11⁄12 | 2 | 0–5 | 17⁄18 | 5⁄2
| Music Disc[A][B] | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1
| Creeper Head[C] | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1

Item | Amount | Probability
--- | --- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0 | 1⁄3 (33.33%) | 1⁄6 (16.67%) | 1⁄12 (8.33%) | 1⁄18 (5.56%)
1 | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 1⁄4 (25.00%) | 1⁄6 (16.67%)
2 | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 5⁄18 (27.78%)
3 | 0 | 1⁄6 (16.67%) | 1⁄4 (25.00%) | 5⁄18 (27.78%)
4 | 0 | 0 | 1⁄12 (8.33%) | 1⁄6 (16.67%)
5 | 0 | 0 | 0 | 1⁄18 (5.56%)
Average | 1 (1.00) | 3⁄2 (1.50) | 2 (2.00) | 5⁄2 (2.50)
| Music Disc[A][B] | 1 | 1 (100.00%) | 1 (100.00%) | 1 (100.00%) | 1 (100.00%)
Average | 1 (1.00) | 1 (1.00) | 1 (1.00) | 1 (1.00)
| Creeper Head[C] | 1 | 1 (100.00%) | 1 (100.00%) | 1 (100.00%) | 1 (100.00%)
Average | 1 (1.00) | 1 (1.00) | 1 (1.00) | 1 (1.00)

Killed | 1
Item | Expected Drops
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 1.00 | 1.50 | 2.00 | 2.50
| Music Disc[A][B] | 1.00 | 1.00 | 1.00 | 1.00
| Creeper Head[C] | 1.00 | 1.00 | 1.00 | 1.00

1. ↑ The disc is randomly selected from 13, cat, blocks, chirp, far, mall, mellohi, stal, strad, ward, 11, and wait.
2. ↑ Only when killed by a skeleton, stray, skeleton horse (via commands), bogged, wither skeleton, or parched.
3. ↑ Only when killed by a charged creeper.

Bedrock Edition:

Item | Quantity / Chance / Average
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0–2 | 66.67% | 1.00 | 0–3 | 66.67% | 1.33 | 0–4 | 66.67% | 1.67 | 0–5 | 66.67% | 2.00
| Music Disc[A][B] | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00
| Creeper Head[C] | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00 | 1 | 100.00% | 1.00

Item | Quantity / Chance / Average
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0–2 | 2⁄3 | 1 | 0–3 | 2⁄3 | 4⁄3 | 0–4 | 2⁄3 | 5⁄3 | 0–5 | 2⁄3 | 2
| Music Disc[A][B] | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1
| Creeper Head[C] | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1 | 1

Item | Amount | Probability
--- | --- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 0 | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 1⁄3 (33.33%)
1 | 1⁄3 (33.33%) | 1⁄6 (16.67%) | 1⁄12 (8.33%) | 1⁄18 (5.56%)
2 | 1⁄3 (33.33%) | 1⁄3 (33.33%) | 1⁄4 (25.00%) | 1⁄6 (16.67%)
3 | 0 | 1⁄6 (16.67%) | 1⁄4 (25.00%) | 2⁄9 (22.22%)
4 | 0 | 0 | 1⁄12 (8.33%) | 1⁄6 (16.67%)
5 | 0 | 0 | 0 | 1⁄18 (5.56%)
Average | 1 (1.00) | 4⁄3 (1.33) | 5⁄3 (1.67) | 2 (2.00)
| Music Disc[A][B] | 1 | 1 (100.00%) | 1 (100.00%) | 1 (100.00%) | 1 (100.00%)
Average | 1 (1.00) | 1 (1.00) | 1 (1.00) | 1 (1.00)
| Creeper Head[C] | 1 | 1 (100.00%) | 1 (100.00%) | 1 (100.00%) | 1 (100.00%)
Average | 1 (1.00) | 1 (1.00) | 1 (1.00) | 1 (1.00)

Killed | 1
Item | Expected Drops
--- | ---
Default | Looting I | Looting II | Looting III
| Gunpowder | 1.00 | 1.33 | 1.67 | 2.00
| Music Disc[A][B] | 1.00 | 1.00 | 1.00 | 1.00
| Creeper Head[C] | 1.00 | 1.00 | 1.00 | 1.00

1. ↑ The disc is randomly selected from 13, cat, blocks, chirp, far, mall, mellohi, stal, strad, ward, 11, and wait.
2. ↑ Only when killed by a skeleton, stray, or bogged.
3. ↑ Only when killed by a charged creeper.

- 5XP experience points, if killed by the player or a tamed wolf.

## Behavior

A creeper giving chase.

Creepers chase any player within a 16-block radius. They chase the player at a 14-block radius when they are crouching. They do not attack any other mob without provocation by being attacked first.

When within 3 blocks of a player, a creeper stops moving, hisses, flashes and expands, and explodes after 1.5 seconds (30 ticks), destroying (and dropping as items) blocks in the area as well as significantly damaging the player. A creeper's detonation can be halted if the player leaves the blast radius, including by knocking it back, going out of the creeper's sight, or if the creeper is killed before the explosion. Assuming the player stays within line of sight, the distance that the player must move in order for a creeper to cancel its explosion is 7 blocks, regardless of difficulty. Normal creeper explosions have a power of 3.

In Java Edition, if the game rule `mobExplosionDropDecay` is set to false, blocks have a 100% chance of dropping as items instead of being destroyed.

A creeper explodes only if it has an uninterrupted line of sight with the player throughout the entire 1.5-second countdown. As a result, if the creeper does not have line-of-sight with the player, it does not start hissing even at close range, even if the player is attacking it, and a detonation is canceled if it has started. The hissing sound plays in its entirety regardless of whether the explosion happens or not.

Unlike most mobs, the creeper does not have an idle sound, nor does it have unique step sounds. Although it does make normal stepping and swimming sounds, it is hard for players to distinguish those from sounds they make themselves. This makes the approach of a creeper difficult for an unwary player to notice until it starts hissing.

A creeper jumps down to a player if it can survive the fall. A creeper taking fall damage adds to its swell according to `fallDistance * 1.5`, up to a maximum of 5 less than the fuse of the creeper. The creeper explodes when the swell equals the fuse, so an explosion occurs soon after landing with higher falls. For example, a creeper falling from greater than 16 blocks can explode 5 ticks after it lands.

The amount of swell added to creepers upon falling a certain distance.

Creepers can climb up ladders, vines, and similar blocks like any other mob, but do not do so intentionally.

Using a flint and steel or fire charge‌[JE only] on a creeper forces an explosion.

In Java Edition, the detection range of creepers is reduced by 50% when the player is wearing a creeper head.

Creepers flee from ocelots and cats within a 6-block radius, with faster movement than when pursuing a player. Cats and ocelots do not attack creepers. A creeper that has begun a detonation does not flee unless the player leaves its blast radius.

Creepers are not targeted by tamed wolves, iron golems or zoglins. However, they are still attacked by withers, snow golems,[1] vindicators named "Johnny", wardens and goats. When hit by a stray projectile (like a drowned's trident), a creeper retaliates if not already chasing a player, unless said projectile is a skeleton's arrow, in which case the creeper will always retaliate. If a creeper is attacked by any mob except a goat, the creeper moves toward the mob that attacked it and explodes.

When a creeper is inflicted with a status effect, its explosion creates an area effect cloud of the effect.‌[Java Edition only]

### Charged creeper

Two creepers' explosion damage radius in the dirt. Comparison between a charged creeper's (left) and a normal creeper's (right). Notice that the charged creeper's explosion is much bigger than the normal creeper's explosion.

Charged creepers are stronger versions of creepers. They are distinguished from normal creepers by their blue aura surrounding them, and their explosion power is significantly increased.

A charged creeper is created when lightning strikes within four blocks of a normal creeper. The lightning can be created in any way, including naturally, with the `/summon` command, by a trident with the Channeling enchantment, or attracted to a lightning rod. Due to this mechanic, creepers cannot be damaged by lightning but still can take damage from fire caused by it.

A charged creeper can also be summoned using the following commands:

- In Java Edition: `/summon creeper ~ ~ ~ {powered:1}`
- In Bedrock Edition: `/summon creeper ~ ~ ~ ~ ~ minecraft:become_charged`

Their countdown timers are the same as normal creepers, both in terms of range and time. With a power of 6, an explosion caused by a charged creeper is twice as powerful as the explosion caused by a creeper. Charged creepers' explosions are 50% more powerful than an explosion of TNT. How close the creeper was to the lightning strike does not affect the size or power of the explosion.

In Java Edition, a charged creeper explosion that kills zombies, skeletons, wither skeletons, piglins, or other creepers causes one[2] of those mobs to drop its corresponding mob head. If multiple valid mobs are killed in the explosion, the one that drops a head is chosen at random. In Bedrock Edition, a charged creeper explosion that kills zombies, skeletons, wither skeletons, piglins, or other creepers causes all the killed mobs to drop their corresponding heads.[3]

A charged creeper does not drop its own head when it explodes, although any other charged creepers or creepers killed in the explosion drop a creeper head. Players and ender dragons do not drop their heads,[4] nor do mobs without corresponding mob heads, such as livestock animals.

Charged creepers have the same entity ID as normal creepers. The only difference is that the value of the boolean `powered` tag is set to `1` (true).

The overlay of charged creepers is strongly emissive with Vibrant Visuals, and darkens the environment as a screen effect. Combined with the darkness of a thunderstorm, this makes the creeper behind it almost invisible.

### Farming

Main article: Tutorial:Creeper farming

## Sounds

Java Edition:

Sounds
Sound | Closed captions | Source | Description | Identifier | Translation key | Volume | Pitch | Attenuation distance
--- | --- | --- | --- | --- | --- | --- | --- | ---
| ​Creeper dies | Hostile Mobs | When a creeper dies without exploding | `entity.creeper.death` | `subtitles.entity.creeper.death`​ | 1.0 | 0.8-1.2 | 16
| ​Creeper hurts | Hostile Mobs | When a creeper is damaged | `entity.creeper.hurt` | `subtitles.entity.creeper.hurt`​ | 1.0 | 0.8-1.2 | 16
| ​Creeper hisses | Hostile Mobs | When a creeper begins its explosion timer | `entity.creeper.primed` | `subtitles.entity.creeper.primed`​ | 1.0 | 0.5 | 16
| ​Explosion | Blocks | When a creeper explodes | `entity.generic.explode` | `subtitles.entity.generic.explode`​ | 4.0 | 0.56-0.84 | 16

Bedrock Edition:

Sounds
Sound | Closed captions [upcoming: BE 26.0] | Source | Description | Identifier | Translation key [upcoming: BE 26.0] | Volume | Pitch
--- | --- | --- | --- | --- | --- | --- | ---
| ​ ? | Hostile Mobs | When a creeper dies | `mob.creeper.death` | ​ ? | 1.0 | 0.8-1.2
| ​ ? | Hostile Mobs | When a creeper is damaged | `mob.creeper.say` | ​ ? | 1.0 | 0.8-1.2
| ​ ? | Blocks | When a creeper begins its explosion timer | `random.fuse` | ​ ? | 1.0 | 0.5
| ​ ? | Blocks | When a creeper explodes | `random.explode` | ​ ? | 4.0 | 1.0

## Data values

### ID

Java Edition:

Name | Identifier | Translation key
--- | --- | ---
Creeper | `creeper` | `entity.minecraft.creeper`

Bedrock Edition:

Name | Identifier | Numeric ID | Family | Translation key
--- | --- | --- | --- | ---
Creeper | `creeper` | `33` | `creeper` `mob` `monster` | `entity.creeper.name`

### Entity data

Creepers have entity data associated with them that contains various properties.

Java Edition:

Main article: Entity format

- [NBT Compound / JSON Object] Entity data
  - Tags common to all entities see Template:Nbt inherit/entity/template
  - Tags common to all mobs see Template:Nbt inherit/mob/template
  - [Byte] ExplosionRadius: The power of the explosion (default value is 3). Despite the name, this represents the explosion power value, so the true radius varies and its maximum is approximately 4/3 times this value.
  - [Short] Fuse: States the initial value of the creeper's internal fuse timer (does not affect creepers that fall and explode upon impacting their victim). The internal fuse timer returns to this value if the creeper is no longer within attack range. Default 30.
  - [Byte] ignited: 1 or 0 (true/false) - Whether the creeper has been ignited by flint and steel.
  - [Byte] powered: 1 or 0 (true/false) - May not exist. True if the creeper is charged from being struck by lightning.

Bedrock Edition:

  See Bedrock Edition level format/Entity format.

## Achievements

Icon | Achievement | In-game description | Actual requirements (if different) | Gamerscore earned | Trophy type (PS)
--- | --- | --- | --- | --- | ---
PS4 | Other
|  | Monster Hunter | Attack and destroy a monster. | Kill one of these 41 monsters: Blaze Bogged Breeze Camel Husk Cave Spider Creaking (by destroying its creaking heart) Creeper Drowned Elder Guardian Ender Dragon Enderman Endermite Evoker Ghast Guardian Hoglin Husk Magma Cube Parched Phantom Piglin Piglin Brute Pillager Ravager Shulker Silverfish Skeleton Slime Spider Stray Vex Vindicator Witch Wither Wither Skeleton Zoglin Zombie Zombie Horse Zombie Nautilus Zombie Villager Zombified Piglin Other mobs may be killed, but are ignored for this achievement. | 15 | Bronze
|  | Camouflage | Kill a mob while wearing the same type of mob head. | — | 30 | Bronze
|  | Archer | Kill a creeper with arrows. | — | 10 | Bronze
|  | It Spreads | Kill a mob next to a catalyst | Kill any mob that drops experience near a sculk catalyst, with the sole exception of the ender dragon. Mobs that drop no experience are ignored for this achievement. | 10 | Bronze

Achievements that apply to all mobs:

Icon | Achievement | In-game description | Actual requirements (if different) | Gamerscore earned | Trophy type (PS)
--- | --- | --- | --- | --- | ---
PS4 | Other
|  | Overkill | Deal nine hearts of damage in a single hit. | Damage can be dealt to any mob, even those that do not have nine hearts of health overall. | 30 | Bronze
|  | Over-Overkill | Deal 50 hearts of damage in a single hit using the Mace | Damage can be dealt to any mob, even those that do not have 50 hearts of health overall. | 20 | Silver
|  | Mob Kabob | Hit five mobs in the same Charge attack using the Spear. | Armor stands and players also count for this achievement as they are technically mobs. | 10 | Bronze

## Advancements

Icon | Advancement | In-game description | Actual requirements (if different)
--- | --- | --- | ---
| Monster Hunter | Kill any hostile monster | Kill one of these 41 monsters: Blaze Bogged Breeze Camel Husk Cave Spider Creaking (by destroying its creaking heart) Creeper Drowned Elder Guardian Ender Dragon Enderman Endermite Evoker Ghast Guardian Hoglin Husk Magma Cube Parched Phantom Piglin Piglin Brute Pillager Ravager Shulker Silverfish Skeleton Slime Spider Stray Vex Vindicator Witch Wither Wither Skeleton Zoglin Zombie Zombie Horse Zombie Nautilus Zombie Villager Zombified Piglin Other mobs may be killed, but are ignored for this advancement.
| It Spreads | Kill a mob near a Sculk Catalyst | Kill any mob that drops experience near a sculk catalyst, with the sole exception of the ender dragon. Mobs that drop no experience are ignored for this advancement.
| Monsters Hunted | Kill one of every hostile monster | Kill each of these 41 monsters: Blaze Bogged Breeze Camel Husk Cave Spider Creaking (by destroying its creaking heart) Creeper Drowned Elder Guardian Ender Dragon Enderman Endermite Evoker Ghast Guardian Hoglin Husk Magma Cube Parched Phantom Piglin Piglin Brute Pillager Ravager Shulker Silverfish Skeleton Slime Spider Stray Vex Vindicator Witch Wither Wither Skeleton Zoglin Zombie Zombie Horse Zombie Nautilus Zombie Villager Zombified Piglin Other mobs may be killed, but are ignored for this advancement.

Advancements that apply to all mobs:

Icon | Advancement | In-game description | Actual requirements (if different)
--- | --- | --- | ---
| Adventure | Adventure, exploration and combat | Kill any mob, or be killed by any living entity.
| A Throwaway Joke | Throw a Trident at something. Note: Throwing away your only weapon is not a good idea. | Hit a mob with a thrown trident.
| Take Aim | Shoot something with an Arrow | Using a bow or a crossbow, shoot a mob with an arrow, tipped arrow, or spectral arrow.
| Mob Kabob | Hit five mobs in the same Charge attack using the Spear. | Armor Stand and Mannequin also count for this advancement.
| Arbalistic | Kill five unique mobs with one crossbow shot | Armor Stand and Mannequin also count for this advancement. This is a hidden advancement, meaning that it can be viewed by the player only after completing it, regardless of if its child advancement(s), if any, have been completed.
| Over-Overkill | Deal 50 hearts of damage in a single hit using the Mace | Damage can be dealt to any mob, even those that do not have 50 hearts of health overall.

## Videos

## Development

This section needs expansion.
You can help by expanding it.

These mobs were originally meant to be a pig, but due to a coding bug, it created a creeper after the model got repurposed.

“

> The story of the Creeper – it was supposed to be the pig, but Notch mixed the height and the width values, or the rotation of it, so it's standing up instead of lain horizontally. But it did have the AI behaviour of looking at the player. So he just thought it was extremely creepy, with this weird thing walking around, looking at you. So he decided to keep it as a monster. He wrote that a friend said it would be cool if it exploded *laughs* and that brought us to the Creeper.

> The face was to clearly, with a limited number of pixels, make it look really dangerous. I think the green colour is supposed to be camouflage. But we're still debating – is it flesh? Or is it more like leaves? Or is it fur? You don't really know just by looking at the pixels. I know Junkboy debates that! *laughs*

„
— JENS BERGENSTEN[5]

## History

### Development

August 20, 2009 | A failed pig model is shown. Notch commented, "it looks creepier when animated ... haha, I'll keep it for a creepy creature. =D".​[more information needed]
September 1, 2009 | Creepers were shown on The Word of Notch.
While the texture itself is bright, creepers appear darker than intended.
Creepers behave much like zombies currently do, hopping around randomly until spotting the player.
The melee attacks of creepers deal only 4HP worth of damage rather than the zombies' 6HP.
When killed, creepers "lie down" like any other dead mob and cause a 4×4×4 spherical explosion that left a sizable crater, destroying plenty of blocks and severely hurting any players nearby.
The creeper is worth 250 points when killed.

### Java Edition

Java Edition Classic
0.24_SURVIVAL_TEST | Added creepers.
0.24_SURVIVAL_TEST_03 | Creeper explosions no longer drop water and lava items when blowing up the liquids.
0.25 SURVIVAL TEST | Mobs, including creepers, are now more dangerous, respawn, despawn, and attack skeletons if shot by them.
October 20, 2009 | Notch mentioned that creepers no longer destroy rock-type blocks.
0.26 SURVIVAL TEST | The texture of creepers has been changed.
The explosions of creepers no longer destroy stone or stone-like blocks.
The explosions of creepers now leave smoldering.
0.27 SURVIVAL TEST | The creeper is now worth 200 points when killed.
Java Edition Indev
0.31 | 20091223-0040 | Creepers and other mobs no longer spawn naturally.
20100202 | The texture of creepers has been changed, it now appears brighter overall.
Creepers and other mobs now spawn naturally again. However, they are currently passive.
20100204-2027 | Creepers are now hostile again, and attack by approaching and exploding near players.[verify] Previously in Survival Test, creepers dealt melee damage and exploded only when killed by the player.
20100219 | Creepers now drop sulphur upon death.
? | Creepers no longer produce leaf particles upon explosion.
Java Edition Alpha
v1.0.3 | Added unique hurt sounds for creepers. Previously, they used the hurt sound for players.
v1.0.14 | Added music discs "13" and "cat", which are dropped by creepers shot by skeletons.
v1.2.0_02 | Creepers now have new hurt sounds. Old hurt sounds:
Java Edition Beta
? | Creeper's fuse timer does not tick back when the player is out of range[verify]
1.3 | Creeper's fuse timer has been fixed
1.4 | The 'A' in the Minecraft logo now includes a creeper face.
1.5 | Creepers now become charged when struck by lightning, increasing the explosion's radius and strength.
1.8 | Pre-release | Creepers are now much more deadly, and can kill an unarmored player, if in a radius of 4 to 5 blocks around the creeper. This damage is also difficulty-independent.
Java Edition
1.0.0 | Beta 1.9 Prerelease 5 | Creepers and other hostile mobs no longer attack the player in Creative mode, unless provoked.
RC1 | Creeper explosions now have a new sound.
1.1 | 11w50a | Creepers now drop all music discs, except for "11".
1.2.1 | 12w05b | Creepers now run away from tamed cats and ocelots.
12w07a | As part of the AI overhaul, creepers no longer attack other mobs.​[more information needed]
Creepers no longer strafe toward the left of the player, now stopping in front of the player.
1.3.1 | 12w30a | Creepers have been made stronger. Depending on difficulty, creeper damage is now scaled, with Easy: ~50% less damage, Normal: same damage as before, and Hard: ~33% more damage than before. In full diamond armor and Hard difficulty, a creeper can knock players down to 2 hearts.[6]
1.4.2 | 12w38b | New creeper fall mechanics have been added; creepers now explode, if they fall on the player from a certain height.
1.4.4 | 1.4.3 | Creepers now drop music discs "11" and "wait".
1.6.1 | 13w18a | Creepers no longer explode when hit in Creative mode.
1.7.2 | 13w36a | Creepers can now be forcibly exploded by using flint and steel.
1.8 | 14w05a | Players can now see from the perspective of a creeper in Spectator mode. A green creeper shader is applied and the player is limited to the creeper's movements.
14w11a | Other creepers, witches, zombies, skeletons, spiders, cave spiders and zombie pigmen now run away from creepers that are about to explode.
14w30a | Charged creepers now cause zombies, skeletons, wither skeletons and other creepers to drop heads.
14w30b | Each charged creeper now causes the drop of only one head, even if multiple head-dropping mobs are killed.
1.8.1 | pre1 | Mobs no longer run from creepers that are about to explode, due to performance issues.
Creepers no longer attack iron golems.
1.9 | 15w32a | The detection range of creepers is halved when the player is wearing a creeper head.
15w33c | The detection range for players wearing the creeper head is adjusted, now 37.5% of the normal range.
15w36a | The detection range for players wearing the creeper head is again 50% of the normal range.
15w39a | Creepers are now slightly shorter (1.7 blocks tall rather than 1.8).
15w51a | Creepers no longer drop music discs when game rule `doMobLoot` is `false`.[7]
1.11 | 16w32a | Creepers that explode while having a potion effect now leave behind an area effect cloud having that effect.
Creepers no longer drop music discs when killed by strays or wither skeletons.[8]
1.14 | 18w43a | Creepers now drop music discs when killed by strays and wither skeletons[a] again.
1.15 | 19w39a | Creepers no longer flash solid white when exploding.[9]
1.17 | 21w15a | Creepers now show no hostility when attacked by a goat.
1.19.3 Experiment Update 1.20 | 22w46a | Charged creepers now cause piglins to drop piglin heads.
1.19.3 | pre2 | Creepers can now be forcibly exploded by using a fire charge.[10]
1.20.3 | 23w40a | Creepers now drop music discs when killed by skeleton horses.[b]

### Bedrock Edition

Pocket Edition Alpha
v0.3.3 | Added creepers.
They do not yet spawn naturally and require external help to spawn.[11]
Creepers currently have old explosion sounds.
Creeper's explosions produce a white mist and have a smaller range.
Creepers strafe toward the left of the player and are as slow as zombies.
v0.4.0 | Creepers now spawn naturally.
v0.7.4 | Tapping and holding flint and steel on a creeper now causes it to automatically explode.
v0.9.0 | build 1 | Creepers no longer float 2 pixels off the ground.
build 2 | An ignite button is now used to automatically explode a creeper when holding flint and steel, instead of tapping and holding.
build 8 | Creepers now use the new AI, so now they avoid fire, cactus, lava, and falling (and water when idle).
build 9 | Creepers now use the old AI again because them walking faster and not detonating.
v0.9.2 | Creepers now have a correct explosion range.
The detonation time for creepers has been fixed (would previously explode almost instantly).
v0.11.0 | build 1 | Creepers can now climb ladders.
v0.12.1 | build 1 | Creepers now use the new AI again, now stopping in front of the player.
The creeper's moving speed and explosions' knockback effect has been increased.
Creepers now explode if they fall on players from a certain height.
Creepers now become charged when struck by lightning, increasing the explosion's radius and strength.
Creepers now have the new explosion sound.
Creepers now have the flashing animation and the explosions have shockwaves.
v0.14.0 | build 1 | Creepers are now slightly shorter (1.7 blocks tall rather than 1.8).
v0.16.0 | build 4 | Creepers now have idle sounds.
Bedrock Edition
1.2.0 | beta 1.2.0.2 | Creepers now drop music discs when killed by skeletons.
1.10.0 | beta 1.10.0.3 | Creepers now drop music discs when killed by strays.
1.16.210 | beta 1.16.210.51 | No longer attack back after being rammed by a goat.
1.20.10 | ? | Creepers bobbing in water in a 1 block space no longer attack a swimming player for 3HP.
1.21.60 | Preview 1.21.60.21 | Creepers no longer flash solid white when exploding.[12]

### Legacy Console Edition

Legacy Console Edition
Xbox 360 | Xbox One | PS3 | PS4 | PS Vita | Wii U | Switch |
--- | --- | --- | --- | --- | --- | --- | ---
TU1 | CU1 | 1.00 | 1.00 | 1.00 | Patch 1 | 1.0.1 | Added creepers.
TU5 | Added charged creepers.
TU12 | Creepers no longer attack other mobs. Before this update, a creeper shot by a skeleton would attack the skeleton, creating a crater in the process.
TU14 | 1.04 | Creepers have been made stronger. Depending on difficulty, creeper damage is scaled now with Easy: ~50% less damage, Normal: same damage as before, and Hard: ~33% more damage than before. In full diamond armor and hard difficulty, a creeper can knock players down to 2 hearts.
A creeper is now aggressive toward the last player that hit it.
The creeper's explosions' knockback effect has been increased.
Creepers now explode if they fall on players from a certain height.
TU24 | CU12 | 1.16 | 1.16 | 1.16 | The creeper's flashing animation has been updated.
TU31 | CU19 | 1.22 | 1.22 | 1.22 | Patch 3 | Creepers can now be forcibly exploded using flint and steel.
Creepers drop a mob head when killed by a charged creeper.
TU54 | CU44 | 1.52 | 1.52 | 1.52 | Patch 24 | 1.0.4 | Creepers that explode while having a potion effect now leave behind an area effect cloud having that effect.
|  |  | 1.90 |  |  |  | Creepers now drop music discs when killed by strays.

### New Nintendo 3DS Edition

New Nintendo 3DS Edition
0.1.0 | Added creepers.

### Data history

Java Edition
1.11 | 16w32a | The namespaced ID of creepers have been changed from `Creeper` to `creeper`.
1.13 | 17w47a | Numeric IDs for entities were presumably deprecated in this version.​[more information needed]

## Issues

Issues relating to "Creeper" are maintained on the bug tracker. Issues should be reported and viewed there.

## Trivia

- Notch has stated on X that he imagined "creepers as being made out of leaves or similar" and that he is "not sure why they explode".[13] When asked to describe its physical texture, he said they would feel "crunchy, like dry leaves".[14]
- Creepers are bright green color to camouflage them for the original classic Minecraft foliage textures, which were bright shades of green, but has since been changed.
- In multiplayer, if a creeper is attacked by another player, and the other player runs out of sight, it does not attack any other players.
- When asked how creepers trigger their explosive nature, Dinnerbone said "They're so nervous that they shake a lot, and then this sets them off the same way as how rubbing two sticks makes fire".[15]
- If a charged creeper is given Invisibility, the "aura" effect is still visible.
- A charged creeper explosion can inflict the greatest amount of damage any mob in the game can do at one time.
- The creeper hiss sound uses the same sound file as when a block of TNT is primed but played at a lower pitch.
- Creeper was the first hostile mob added in the survival test.
- Throughout many pieces of media, whenever a creeper's anatomy is shown it's consistently shown they possess a skeleton and a TNT block inside.[16][17][18][19]
  - This is even present in the Minecraft Dungeons creeper.
- Jeb has admitted that the creeper would probably not be added to Minecraft if the game's modern design principles were followed, since it would be controversial to have a mob that destroys the player's builds. However, it continues to exist in the game due to its iconic status.[20] Notch agreed, stating that the creeper only explodes as the result of player (in-)action because random destructive events you have no control over is anti-fun.[21]

### Publicity

A sight that can scare even the most experienced Minecraft players.

Creepers have a formidable reputation in the community because of their potential to hurt or kill even veteran players and destroy structures. Their distinct appearance and destructive abilities have made them a widely recognizable Minecraft icon. Creepers are referenced in several of the items available at the Minecraft merchandise depot,[22] and have become an internet meme complete with fan art, webcomic references, and demotivational posters. A central part of the meme is the creeper's unofficial catchphrase derived from the mob's tendency to sneak up on the player and hiss before detonating:

“

> That'sssss a very nice <random valuable object> you've got there... It'd be a ssssshame if anything were to happen to it...

„
— Creepers[23]

#### Merchandise

Creepers have been portrayed in many Minecraft products including but not limited to:

- The letter "A" in the Minecraft logo after Java Edition Beta 1.4 (The previous logo was just "MINECRAFT" written with cobblestone blocks)
- Stuffed toys
- Action figures
- Bracelets
- T-shirts
  - The creeper anatomy T-shirt reveals the insides of a creeper, and also reveals its scientific name: Creepus explodus.
- LEGO Minecraft
- Papercraft
- Minecraft Facebook profile image
- In the goodie bags given out at Minecon 2011, creepers were given as a fold-able and tapable decoration for one's room or collection, along with diamond and grass block.

#### Appearances

A creeper and a chest sent to the edge of space by the Physics Society Outreach Project
Main article: Minecraft in popular culture

- On June 18, 2012, the University of Southampton Physics Society Outreach Project sent a creeper and chest to the edge of space in a balloon with a tracker and camera.[24]
- As part of an official collaboration, creepers are included as monsters in Monstrous Compendium Volume Three: Minecraft Creatures, a free add-on for the roleplaying game Dungeons & Dragons.[25] In the game, they are "Monstrosities" and have the alignment "Typically Neutral Evil".

#### Games

Name | Image | Description | Date
--- | --- | --- | ---
Sonic Racing: CrossWorlds |  | The Creeper will be a playable character in the Season Pass and Digital Deluxe Edition of the game, alongside Steve and Alex. | 2025

## Gallery

### Textures

- Texture of a creeper.
- Charged creeper overlay.
- Texture of a smiling creeper.
- Original texture file of the creeper. Notice the leaves.

### Screenshots

- A creeper staring at the player.
- A creeper that is about to explode.
- Creeper explosion.
- Comparison of explosion craters. From left to right: charged creeper, TNT, creeper.
- A creeper dying.
- A creeper's vision when spectating it.
- A forest at night through a creeper's eyes.
- A creeper explosion that damaged a village house.
- A rudimentary example of a music disc farm.
- Creeper peeking through a glass window.
- A charged creeper next to a normal creeper.
- Creeper face-shaped firework.

### Historical screenshots

- The original dark green creeper model.

### Mojang images

- Steve standing next to a creeper
- Ari trying to land a hit on a creeper with a mace
- A moment before disaster. Note: This image was taken in Bedrock Edition before 1.21.60.
- Efe fleeing from a creeper
- A three-headed creeper, demonstrating custom entity models in Bedrock Edition

### Historical Mojang images

- The original pig model the creeper was based on.

### In other media

#### Official media

- Artwork of the creeper.
- Artwork of a creeper.
- Artwork of a creeper's face.
- Creeper art
- A creeper in promotional artwork for the first Caves & Cliffs update.
- Creepers in promotional artwork for the second Caves & Cliffs update.
- A creeper in official artwork for The Wild Update.
- Artwork of a creeper used to signal the end of account migration.
- Artwork for the Minecraft Spookyfest event, featuring a creeper.
- A minecraft.net maintenance screen featuring creepers.
- Gamerpic award from Xbox 360 Edition.
- Gamerpic from the "Minecraft Faces" pack.
- Gamerpic from the "Minecraft Mobs in Suits 2" pack.
- Promotional artwork for a Minecraft collaboration with Kellogg’s Frosted Flakes.
- A baby creeper in 15 Year Journey.
- “Creepy,” a ghost resembling a creeper featured in the Pac-Man DLC.
- A Chao resembling a creeper, featured in the Sonic the Hedgehog DLC.
- Artwork of a creeper as it appears in the Sonic Texture Pack. Notice the robotic look.
- Animated creeper artwork.
- Creepers representing Minecraft Dungeons, Minecraft Legends, and Minecraft looking at each other.[26]
- Minecraft-themed word search.
- A creeper with muscular human arms.
- A creeper peeking out from a tree near some mushrooms.
- A creeper peeking out from a tree near a fox and a pillager.
- Potato Creeper in 24w14potato snapshot
- World Kindness Day artwork.
- Creeper in a pair of pants.
- A creeper waving hello with one of its legs.
- Creeper in Hour of Code.
- A creeper as it appears in A Minecraft Movie.
- A Creeper peeking through an IRL window.
- Creeper photo in a yearbook.

#### Merchandise

- A photograph featuring many pieces of official creeper merchandise.
- A creeper face shirt.
- A creeper face shirt.
- A creeper riding a bike.
- Official artwork "Creeper Anatomy" for merchandise made by JINX.
- Official artwork "Creepers Gonna Creep" for merchandise made by JINX.
- Official artwork "Drop it Creep" for merchandise made by JINX.
- Official T-shirt artwork "Retro Creeper" made by JINX.
- Official T-shirt artwork "Three Creeper Moon" made by JINX. The name and graphics are a reference to Three Wolf Moon.[27]
- Official T-shirt artwork "Demolition Company" made by JINX.
- Official T-shirt artwork "Glyph" made by JINX.
- "Rainbow Creeper," an official T-Shirt design sold to celebrate Pride Month.
- "Minecraft Seasons Greetings Creeper Ugly Holiday Sweater"
- Official creeper premium zip-up hoodie made by JINX.
- Official T-shirt artwork "Creeper Inside" made by JINX.
- Official sticker "Creeper Inside" made by JINX.
- Official wall decal "Creeper Inside" made by JINX.
- Official sticker "Creeper SSSsss" made by JINX.
- Official creeper face sticker made by JINX.
- Official poster made by JINX that features a creeper.
- Official creeper plushy with sound made by JINX.
- Official creeper vinyl minifigure made by JINX.
- Official creeper vinyl minifigure made by JINX.
- Official creeper action figure made by JINX.
- Charged creeper action figure.
- Official poppable 5-inch Creeper figure by JINX.
- Official creeper vinyl minifigure made by JINX.
- Official creeper face mug made by JINX.
- Official creeper hat made by JINX.
- Official creeper hat made by JINX.
- Official creeper head cosmetic made by JINX.
- Official creeper bracelet made by JINX.
- Official creeper pendant on a necklace made by JINX.
- Official creeper wallet made by JINX.
- Official creeper beanie made by JINX.
- Official creeper scarf by JINX.
- Official creeper plushies made by JINX.
- A Minecraft creeper backpack from ThinkGeek.
- "Minecraft Digital Print," a design featured on a throw blanket.
- Creeper and Steve micromobs from official LEGO Minecraft.
- Creeper minifigure from official LEGO Minecraft.
- Charged creeper minifigure.
- Exploding creeper minifigure.
- An enchanted creeper minifigure.
- BrickHeadz of Steve and a creeper.
- A Creeper Bigfig LEGO Minecraft set.
- A Creeper Mine LEGO Minecraft set.
- A Steve and Creeper LEGO Minecraft set.
- Official creeper toaster.
- Greek Mythology mash-up pack
- City texture pack
- Creeper Steve Boxhead, a skin featured in the 1st Birthday skin pack.
- Halloween mash-up pack
- Party Creeper, another skin featured in the 1st Birthday skin pack.
- Creeper figure of Flippin' Figs
- Charged Creeper figure of Flippin' Figs
- A bunch of creeper-themed merchandise.
- Creeper bearbrick figure.
- Creeper figure and plush.
- Creeper plushes.
- Creeper plush.
- Creeper plush.
- A creeper wall clock

#### Other appearances

- The Creeper Mii Brawler costume in Super Smash Bros. Ultimate.
- Creeper Spirit from Super Smash Bros. Ultimate.
- A creeper as it appears on the cover of Minecraft: Mob Squad: Don't Fear the Creeper.
- A creeper as depicted on the cover of the Mobestiary.
- Anatomy of a creeper, as seen in the Mobestiary.
- The official creeper statistics in the Monstrous Compendium Volume Three: Minecraft Creatures.
- A creeper Easter egg that can be found in a game called Stick RPG 2.
- The Geometry Dash achievement that unlocks a creeper icon.
- The creeper from Henry Stickmin.
- The Creeper set from Terraria.
- The Secret Creeper, featured in the Trails & Tales Event.
- Tiny Creeper, featured in 2023 Mob Vote Event.
- Target of a creeper in a cowboy hat from the Universal Studios Event.
- Ditto, but with a charged creeper in a cowboy hat.
- A creeper face hidden amongst other doodles in a wallpaper of the WhatsApp application near the bottom left
- A creeper statue.

## Notes

1. ↑ Wither skeletons can be given the ability to damage creepers only through commands, such as being given a bow.
2. ↑ This can only happen via the damage command, as skeleton horses don't have a natural way to harm other entities.

## References

1. ↑ MC-73964 — Snow golems can attack creepers
2. ↑ MC-63534 — Only one mob skull can be dropped if a Charged Creeper kills several mobs of the same type. — resolved as "Works As Intended".
3. ↑ MCPE-18599 — Multiple Mob Head Drops from Charged Creeper
4. ↑ MC-132933 — Inconsistency: Player, Ender Dragon, and Wither don't drop their heads when killed by charged creeper — resolved as "Works As Intended".
5. ↑ https://www.minecraft.net/en-us/article/meet-creeper
6. ↑ "@Biffa2001 @xisumavoid Most likely. In full diamond armour + hard difficulty a creeper can knock you down to 2hearts!" – @Dinnerbone (Nathan Adams) on X (formerly Twitter), July 23, 2012
7. ↑ MC-51725 — Gamerule doMobLoot does not affect the dropping of music discs — resolved as "Fixed".
8. ↑ MC-112579
9. ↑ MC-47941 — TNT/Creepers flash solid white when exploding — resolved as "Fixed".
10. ↑ MC-185618 — Creepers can't be ignited with a fire charge — resolved as "Fixed".
11. ↑ https://youtu.be/vG167PET3o0
12. ↑ MCPE-51809 — TNT/Creepers flash solid white when exploding — resolved as "Fixed".
13. ↑ "@jeremybenthamm I imagine them as being made out of leaves or similar. I'm not sure why they explode." (archived) – @notch (Markus Persson) on X (formerly Twitter), October 19, 2010
14. ↑ "@jazmcdougall I've imagined them as being crunchy, like dry leaves." – @notch (Markus Persson) on X (formerly Twitter), October 15, 2010
15. ↑ "@Graphoniac They're so nervous that they shake a lot, and then this sets them off the same way as how rubbing two sticks makes fire." – @Dinnerbone (Nathan Adams) on X (formerly Twitter), December 5, 2013
16. ↑ "Minecraft Creeper Skeleton Vintage Cap" – Minecraft.net.
17. ↑ "Mattel - Minecraft TNT Series 25 Mini Figure - CREEPER SKELETON (1 inch)(Loose)" – Walmart.
18. ↑ "Minecraft Creeper Anatomy Vinyl" – Walmart.
19. ↑ "Minecraft Creeper Anatomy from Spin Master" – TTPM Toy Reviews on YouTube, July 23, 2014
20. ↑ "The Biome that Broke Minecraft" – Minecraft on YouTube, October 12, 2025
21. ↑ "I've been seeing a lot of Jeb hate over him saying the creeper's only around because it's iconic, and I'd like to set something straight.
    This is originally one of MY opinions.
    I tried to fix the creeper by having it only explode as the result of player (in-)action, as I realized random destructive events you have no control over is anti-fun." – @notch (Markus Persson) on X (formerly Twitter), October 25, 2025
    "This may also be because they're gearing towards changing every texture in Minecraft for some unknown reason, and many people have pointed out that they would change the creeper's texture if they could. But they can't because it's too iconic" – @SkiBall3148 on X (formerly Twitter), October 25, 2025
    "That's one's true though.
    Wow, I really kick ass at failing to make a pig.
    Maybe that's my true calling." – @notch (Markus Persson) on X (formerly Twitter), October 25, 2025
22. ↑ Official Minecraft Store
23. ↑ "Minecraft Creeper" – Know Your Meme.
24. ↑ "Physoc Outreach" (archived) – Ben Oxley, June 18, 2012.
25. ↑ https://www.dndbeyond.com/claim/source/minecraft-creatures-monstrous-compendium
26. ↑ "👉 👈
    ... 👆" – @Minecraft (Minecraft) on X (formerly Twitter), June 23, 2024
27. ↑ https://www.escapistmagazine.com/jinx-and-mojang-team-up-for-official-minecraft-merchandise/

## External links

- "Meet the Creeper" by Tom Stone – Minecraft.net, May 15, 2017.
- Creeper (Minecraft) – Wikipedia.org

## Navigation

This is a featured article. See Minecraft Wiki:Featured articles for more information.
Retrieved from "https://minecraft.wiki/w/Creeper?oldid=3395283"
Categories:

- Entities
- Featured articles
- Hostile mobs
- Monster mobs

Hidden categories:

- Pages using simple calculator
- Pages with sound tables
- Pages with Java sound tables
- Pages missing subtitles
- Pages missing subtitle key
- Pages with Bedrock sound tables
- Pages with YouTube videos
- Articles to be expanded
- Information needed
- Verify
- Unknown Java Indev version history
- Unknown Java Beta version history
- Unknown Bedrock version history